==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/LoadBalancer/Push_Handler.h <==
// -*- C++ -*-

//=======================================================================
/**
 *  @file    Push_Handler.h
 *
 *  Push_Handler.h,v 1.3 2004/02/04 20:20:19 parsons Exp
 *
 *  @author  Ossama Othman <ossama@uci.edu>
 */
//=======================================================================


#ifndef TAO_LB_PUSH_HANDLER_H
#define TAO_LB_PUSH_HANDLER_H

#include /**/ "ace/pre.h"

#include "ace/config-all.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "orbsvcs/orbsvcs/CosLoadBalancingC.h"

#include "ace/Event_Handler.h"


/**
 * @class TAO_LB_Push_Handler
 *
 * @brief Event handler used when the "push" monitoring style is
 *        configured.
 *
 * An event handler designed to push loads to the LoadManager.
 */
class TAO_LB_Push_Handler : public ACE_Event_Handler
{
public:

  /// Constructor
  TAO_LB_Push_Handler (CosLoadBalancing::LoadMonitor_ptr monitor,
                       const PortableGroup::Location & location,
                       CosLoadBalancing::LoadManager_ptr manager);

  /// Receive the timeout event.
  virtual int handle_timeout (const ACE_Time_Value &current_time,
                              const void *arg);

private:

  /// Reference to the LoadMonitor.
  CosLoadBalancing::LoadMonitor_var monitor_;

  /// Location where the LoadMonitor resides.
  const PortableGroup::Location location_;

  /// Reference to the LoadManager.
  CosLoadBalancing::LoadManager_var manager_;

};

#include /**/ "ace/post.h"

#endif  /* TAO_LB_PUSH_HANDLER_H */

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/LoadBalancer/Push_Handler.h <==
// -*- C++ -*-

//=======================================================================
/**
 *  @file    Push_Handler.h
 *
 *  Push_Handler.h,v 1.4 2004/08/16 23:53:11 jtc Exp
 *
 *  @author  Ossama Othman <ossama@uci.edu>
 */
//=======================================================================


#ifndef TAO_LB_PUSH_HANDLER_H
#define TAO_LB_PUSH_HANDLER_H

#include /**/ "ace/pre.h"

#include "ace/config-all.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "orbsvcs/CosLoadBalancingC.h"

#include "ace/Event_Handler.h"


/**
 * @class TAO_LB_Push_Handler
 *
 * @brief Event handler used when the "push" monitoring style is
 *        configured.
 *
 * An event handler designed to push loads to the LoadManager.
 */
class TAO_LB_Push_Handler : public ACE_Event_Handler
{
public:

  /// Constructor
  TAO_LB_Push_Handler (CosLoadBalancing::LoadMonitor_ptr monitor,
                       const PortableGroup::Location & location,
                       CosLoadBalancing::LoadManager_ptr manager);

  /// Receive the timeout event.
  virtual int handle_timeout (const ACE_Time_Value &current_time,
                              const void *arg);

private:

  /// Reference to the LoadMonitor.
  CosLoadBalancing::LoadMonitor_var monitor_;

  /// Location where the LoadMonitor resides.
  const PortableGroup::Location location_;

  /// Reference to the LoadManager.
  CosLoadBalancing::LoadManager_var manager_;

};

#include /**/ "ace/post.h"

#endif  /* TAO_LB_PUSH_HANDLER_H */
